@@ -1,4 +1,4 @@
-# $Id: mirror_sites.tcl 55615 2009-08-14 21:14:48Z ryandesign@macports.org $
+# $Id: mirror_sites.tcl 68253 2010-05-29 23:39:16Z jmr@macports.org $
 # mirror_sites.tcl
 #
 # List of master site classes for use in Portfiles
@@ -29,12 +29,9 @@ set portfetch::mirror_sites::sites(apache) {
     http://mirror.internode.on.net/pub/apache/
     http://mirror.pacific.net.au/pub1/apache-dist/
     http://apache.wildit.net.au/
-    ftp://ftp.pop-mg.com.br/data/apache/dist/
     http://www.mirrorservice.org/sites/ftp.apache.org/
     http://mirror.aarnet.edu.au/pub/apache/
-    http://apache.mirror.phpchina.com/
     http://apache-mirror.dkuug.dk/
-    http://apache.digimirror.nl/
     http://apache.is.co.za/
     http://www.apache.org/dist/
     http://archive.apache.org/dist/
@@ -45,33 +42,33 @@ set portfetch::mirror_sites::sites(apache) {
 # port name) so just use a basic form here and fake it in ports that need
 # to use this.
 set portfetch::mirror_sites::sites(debian) {
-    ftp://ftp.us.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.au.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.bg.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.cl.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.cz.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.de.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.ee.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.es.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.fi.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.fr.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.hk.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.hr.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.hu.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.ie.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.is.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.it.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.jp.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.nl.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.no.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.pl.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.ru.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.se.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.si.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.sk.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.uk.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp.wa.au.debian.org/debian/pool/main/:nosubdir
-    ftp://ftp2.de.debian.org/debian/pool/main/:nosubdir
+    http://ftp.us.debian.org/debian/pool/main/:nosubdir
+    http://ftp.au.debian.org/debian/pool/main/:nosubdir
+    http://ftp.bg.debian.org/debian/pool/main/:nosubdir
+    http://ftp.cl.debian.org/debian/pool/main/:nosubdir
+    http://ftp.cz.debian.org/debian/pool/main/:nosubdir
+    http://ftp.de.debian.org/debian/pool/main/:nosubdir
+    http://ftp.ee.debian.org/debian/pool/main/:nosubdir
+    http://ftp.es.debian.org/debian/pool/main/:nosubdir
+    http://ftp.fi.debian.org/debian/pool/main/:nosubdir
+    http://ftp.fr.debian.org/debian/pool/main/:nosubdir
+    http://ftp.hk.debian.org/debian/pool/main/:nosubdir
+    http://ftp.hr.debian.org/debian/pool/main/:nosubdir
+    http://ftp.hu.debian.org/debian/pool/main/:nosubdir
+    http://ftp.ie.debian.org/debian/pool/main/:nosubdir
+    http://ftp.is.debian.org/debian/pool/main/:nosubdir
+    http://ftp.it.debian.org/debian/pool/main/:nosubdir
+    http://ftp.jp.debian.org/debian/pool/main/:nosubdir
+    http://ftp.nl.debian.org/debian/pool/main/:nosubdir
+    http://ftp.no.debian.org/debian/pool/main/:nosubdir
+    http://ftp.pl.debian.org/debian/pool/main/:nosubdir
+    http://ftp.ru.debian.org/debian/pool/main/:nosubdir
+    http://ftp.se.debian.org/debian/pool/main/:nosubdir
+    http://ftp.si.debian.org/debian/pool/main/:nosubdir
+    http://ftp.sk.debian.org/debian/pool/main/:nosubdir
+    http://ftp.uk.debian.org/debian/pool/main/:nosubdir
+    http://ftp.wa.au.debian.org/debian/pool/main/:nosubdir
+    http://ftp2.de.debian.org/debian/pool/main/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(freebsd) {
@@ -95,6 +92,53 @@ set portfetch::mirror_sites::sites(freebsd) {
     ftp://ftp.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
 }
 
+# curl -s http://www.gentoo.org/main/en/mirrors2.xml | sed -n '/(http)\|(ftp)/s/.*"\([^"]*\)".*/    \1\/distfiles\/:nosubdir/p' | sed s@//distfiles@/distfiles@g
+set portfetch::mirror_sites::sites(gentoo) {
+    http://gentoo.arcticnetwork.ca/distfiles/:nosubdir
+    http://gentoo.mirrors.tera-byte.com/distfiles/:nosubdir
+    http://mirror.mcs.anl.gov/pub/gentoo/distfiles/:nosubdir
+    http://gentoo.localhost.net.ar/distfiles/:nosubdir
+    http://gentoo.c3sl.ufpr.br/distfiles/:nosubdir
+    http://gentoo.inode.at/distfiles/:nosubdir
+    http://mirror.bih.net.ba/gentoo/distfiles/:nosubdir
+    http:/distfiles.gentoo.bg/distfiles/:nosubdir
+    http://ftp.fi.muni.cz/pub/linux/gentoo/distfiles/:nosubdir
+    http://ftp.klid.dk/ftp/gentoo/distfiles/:nosubdir
+    http://trumpetti.atm.tut.fi/gentoo/distfiles/:nosubdir
+    ftp://ftp.free.fr/mirrors/ftp.gentoo.org/distfiles/:nosubdir
+    http://mirrors.linuxant.fr/distfiles.gentoo.org/distfiles/:nosubdir
+    http://de-mirror.org/distro/gentoo/distfiles/:nosubdir
+    http://files.gentoo.gr/distfiles/:nosubdir
+    http://gentoo.inf.elte.hu/distfiles/:nosubdir
+    http://ftp.rhnet.is/pub/gentoo/distfiles/:nosubdir
+    http://ftp.heanet.ie/pub/gentoo/distfiles/:nosubdir
+    http://gentoo.tups.lv/source/distfiles/:nosubdir
+    http://mirror.elen.ktu.lt/gentoo/distfiles/:nosubdir
+    http://mirror.cambrium.nl/pub/os/linux/gentoo/distfiles/:nosubdir
+    http://gentoo.tiscali.nl/distfiles/:nosubdir
+    http://mirror.gentoo.no/distfiles/:nosubdir
+    http://gentoo.prz.rzeszow.pl/distfiles/:nosubdir
+    http://darkstar.ist.utl.pt/gentoo/distfiles/:nosubdir
+    http://mirrors.evolva.ro/gentoo/distfiles/:nosubdir
+    http://gentoo.ynet.sk/pub/distfiles/:nosubdir
+    http://gentoo-euetib.upc.es/mirror/gentoo/distfiles/:nosubdir
+    http://ftp.ds.karen.hj.se/gentoo/distfiles/:nosubdir
+    http://mirror.switch.ch/ftp/mirror/gentoo/distfiles/:nosubdir
+    http://ftp.linux.org.tr/gentoo/distfiles/:nosubdir
+    http://mirror.bytemark.co.uk/gentoo/distfiles/:nosubdir
+    http://www.mirrorservice.org/sites/www.ibiblio.org/gentoo/distfiles/:nosubdir
+    http://gentoo.kiev.ua/ftp/distfiles/:nosubdir
+    http://mirror.pacific.net.au/linux/Gentoo/distfiles/:nosubdir
+    http://ftp.swin.edu.au/gentoo/distfiles/:nosubdir
+    http://ftp.iij.ad.jp/pub/linux/gentoo/distfiles/:nosubdir
+    http://mirror2.corbina.ru/gentoo-distfiles/distfiles/:nosubdir
+    http://ftp.kaist.ac.kr/pub/gentoo/distfiles/:nosubdir
+    http://ftp.ncnu.edu.tw/Linux/Gentoo/distfiles/:nosubdir
+    http://gentoo.in.th/distfiles/:nosubdir
+    http://mirror.isoc.org.il/pub/gentoo/distfiles/:nosubdir
+    http://mirror.neolabs.kz/gentoo/pub/distfiles/:nosubdir
+}
+
 set portfetch::mirror_sites::sites(gimp) {
     ftp://ftp.gimp.org/pub/
     ftp://ftp.gtk.org/pub/
@@ -119,7 +163,7 @@ set portfetch::mirror_sites::sites(gnome) {
     http://www.gtlib.cc.gatech.edu/pub/gnome/
     http://www.mirrorservice.org/sites/ftp.gnome.org/pub/GNOME/
     http://fr2.rpmfind.net/linux/gnome.org/
-    http://mirror.aarnet.edu.au/pub/GNOME/
+    http://mirror.aarnet.edu.au/pub/gnome/
     http://ftp.unina.it/pub/linux/GNOME/
     http://ftp.acc.umu.se/pub/GNOME/
     http://ftp.belnet.be/mirror/ftp.gnome.org/
@@ -130,6 +174,8 @@ set portfetch::mirror_sites::sites(gnome) {
     ftp://ftp.chg.ru/pub/X11/gnome/
     ftp://ftp.kddlabs.co.jp/pub/GNOME/
     http://mirror.internode.on.net/pub/gnome/
+    http://ftp.df.lth.se/pub/gnome/
+    http://linorg.usp.br/gnome/
     http://ftp.gnome.org/pub/GNOME/
 }
 
@@ -147,14 +193,12 @@ set portfetch::mirror_sites::sites(gnu) {
     http://mirror.internode.on.net/pub/gnu/
     http://mirror.pacific.net.au/pub1/gnu/gnu/
     http://mirror.aarnet.edu.au/pub/GNU/
-    ftp://ftp.unicamp.br/pub/gnu/
     ftp://ftp.gnu.org/gnu/
     http://ftp.gnu.org/gnu/
     ftp://ftp.gnu.org/old-gnu/
 }
 
 set portfetch::mirror_sites::sites(gnupg) {
-    http://gulus.USherbrooke.ca/pub/appl/GnuPG/
     http://www.mirrorservice.org/sites/ftp.gnupg.org/gcrypt/
     http://ftp.freenet.de/pub/ftp.gnupg.org/gcrypt/
     http://www.ring.gr.jp/pub/net/gnupg/
@@ -213,19 +257,16 @@ set portfetch::mirror_sites::sites(kde) {
 set portfetch::mirror_sites::sites(macports) {
     http://svn.macports.org/repository/macports/distfiles/
     http://svn.macports.org/repository/macports/distfiles/general/:nosubdir
-    http://svn.macports.org/repository/macports/downloads/
 }
 
 set portfetch::mirror_sites::sites(macports_distfiles) {
     http://distfiles.macports.org/:mirror
-    http://arn.se.distfiles.macports.org/:mirror
     http://aarnet.au.distfiles.macports.org/pub/macports/mpdistfiles/:mirror
+    http://lil.fr.distfiles.macports.org/:mirror
 }
 
 set portfetch::mirror_sites::sites(openbsd) {
-    http://mirror.roothell.org/pub/OpenBSD/
     http://www.mirrorservice.org/sites/ftp.openbsd.org/pub/OpenBSD/
-    http://ftp-stud.fht-esslingen.de/pub/OpenBSD/
     ftp://carroll.cac.psu.edu/pub/OpenBSD/
     ftp://openbsd.informatik.uni-erlangen.de/pub/OpenBSD/
     ftp://gd.tuwien.ac.at/opsys/OpenBSD/
@@ -266,7 +307,6 @@ set portfetch::mirror_sites::sites(php) {
     http://fi.php.net/distributions/:nosubdir
     http://fr.php.net/distributions/:nosubdir
     http://gr.php.net/distributions/:nosubdir
-    http://it2.php.net/distributions/:nosubdir
     http://www.php.net/distributions/:nosubdir
 }
 
@@ -299,7 +339,7 @@ set portfetch::mirror_sites::sites(ruby) {
 }
 
 set portfetch::mirror_sites::sites(savannah) {
-    http://download.savannah.nongnu.org/releases-noredirect/
+    http://download.savannah.gnu.org/releases-noredirect/
     http://ftp.cc.uoc.gr/mirrors/nongnu.org/
     http://ftp.twaren.net/Unix/NonGNU/
     ftp://ftp.twaren.net/Unix/NonGNU/
@@ -307,10 +347,8 @@ set portfetch::mirror_sites::sites(savannah) {
     ftp://mirror.cinquix.com/pub/savannah/
     http://mirror.csclub.uwaterloo.ca/nongnu/
     ftp://mirror.csclub.uwaterloo.ca/nongnu/
-    http://mirror.dknss.com/nongnu/
     http://mirror.publicns.net/pub/nongnu/
     ftp://mirror.publicns.net/pub/nongnu/
-    http://mirror.sourceshare.org/savannah/
     ftp://mirrors.localhost.net.ar/pub/mirrors/savannah-nongnu/
     http://mirrors.openfountain.cl/savannah/
     http://mirrors.zerg.biz/nongnu/
@@ -318,17 +356,13 @@ set portfetch::mirror_sites::sites(savannah) {
     http://nongnu.bigsearcher.com/
     http://mirror.its.uidaho.edu/pub/savannah/
     ftp://mirror.its.uidaho.edu/savannah/
-    http://nongnu.mirror.ironie.org/
-    ftp://ftp.ironie.org/savannah.nongnu.org/
     http://piotrkosoft.net/pub/mirrors/savannah.gnu.org/
     ftp://ftp.piotrkosoft.net/pub/mirrors/savannah.gnu.org/
     http://savannah.c3sl.ufpr.br/
     ftp://savannah.c3sl.ufpr.br/savannah-nongnu/
     http://savannah.inetbridge.net/
-    http://savannah.releasenotes.org/
     http://www.centervenus.com/mirrors/nongnu/
     http://www.de-mirrors.de/nongnu/
-    http://www.very-clever.com/download/nongnu/
 }
 # Alias nongnu to savannah
 set portfetch::mirror_sites::sites(nongnu) $portfetch::mirror_sites::sites(savannah)
@@ -407,10 +441,7 @@ set portfetch::mirror_sites::sites(tex_ctan) {
 
 set portfetch::mirror_sites::sites(trolltech) {
     ftp://ftp.trolltech.com/qt/source/:nosubdir
-    http://wftp.tu-chemnitz.de/pub/Qt/qt/source/:nosubdir
     http://ftp.heanet.ie/mirrors/ftp.trolltech.com/pub/qt/source/:nosubdir
-    http://mirror.aarnet.edu.au/pub/qt/source/:nosubdir
-    http://ftp.ntua.gr/pub/X11/Qt/qt/source/:nosubdir
     ftp://ftp.informatik.hu-berlin.de/pub1/Mirrors/ftp.troll.no/QT/qt/source/:nosubdir
 }
 
