@@ -1,27 +1,22 @@
---- src/prefops.c.orig	2009-02-01 11:40:50.000000000 -0500
-+++ src/prefops.c	2009-02-01 11:41:28.000000000 -0500
-@@ -72,18 +72,18 @@
-   /* Reasonable default values */
- 
-   ret->lilypath = g_string_new ("lilypond");
+--- src/prefops.c.orig	2009-09-07 09:00:16.000000000 -0300
++++ src/prefops.c	2009-09-07 09:05:42.000000000 -0300
+@@ -88,13 +88,13 @@
+   ret->texteditor = g_string_new ("wordpad");
+   ret->midiplayer = g_string_new("wmplayer");
+ #else /* !G_OS_WIN32 */
+-  ret->browser = g_string_new ("firefox");
 -  ret->midiplayer = g_string_new ("playmidi");
 -  ret->audioplayer = g_string_new ("play");
++  ret->browser = g_string_new ("open");
 +  ret->midiplayer = g_string_new ("qtplay");
 +  ret->audioplayer = g_string_new ("qtplay");
-   ret->csoundcommand = g_string_new ("csound -dm6");
--  ret->browser = g_string_new ("firefox");
-+  ret->browser = g_string_new ("open");
-   ret->csoundorcfile = g_string_new ("");
+   ret->lilypath = g_string_new ("lilypond");
 -  ret->pdfviewer = g_string_new ("xpdf");
-+  ret->pdfviewer = g_string_new ("open");
-   ret->sequencer = g_string_new ("/dev/sequencer");
-   ret->midi_in = g_string_new ("/dev/midi");
- 
- 
 -  ret->imageviewer = g_string_new ("eog");
 -  ret->texteditor = g_string_new ("xedit");
++  ret->pdfviewer = g_string_new ("open");
 +  ret->imageviewer = g_string_new ("open");
 +  ret->texteditor = g_string_new ("smultron");
-   ret->denemopath = g_string_new (g_get_home_dir());
-   ret->lilyversion = g_string_new (LILYPOND_VERSION);
-   ret->temperament = g_string_new("Equal");
+ #endif /* !G_OS_WIN32 */
+   ret->sequencer = g_string_new ("/dev/sequencer");
+   ret->midi_in = g_string_new ("/dev/midi");
